==> dhall-bash-1.0.40-263-riscv64.pkg.tar.zst: usr/share/haskell/register/dhall-bash.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 dhall-bash
version:              1.0.40
visibility:           public
id:                   dhall-bash-1.0.40-JjzPuQtpA1gDxygOUbFu35
key:                  dhall-bash-1.0.40-JjzPuQtpA1gDxygOUbFu35
license:              BSD-3-Clause
copyright:            2017 Gabriel Gonzalez
maintainer:           Gabriel439@gmail.com
author:               Gabriel Gonzalez
synopsis:             Compile Dhall to Bash
description:
    Use this package if you want to compile Dhall expressions to Bash.
    You can use this package as a library or an executable:

    * See the "Dhall.Bash" module if you want to use this package as a library

    * Use the @dhall-to-bash@ if you want an executable

    The "Dhall.Bash" module also contains instructions for how to use this
    package

category:             Compiler
abi:                  829688342d3288a02f2cf61418e42a04
exposed:              True
exposed-modules:      Dhall.Bash
import-dirs:          /usr/lib/ghc-9.2.8/site-local/dhall-bash-1.0.40
library-dirs:         /usr/lib/ghc-9.2.8/site-local/dhall-bash-1.0.40
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/dhall-bash
hs-libraries:         HSdhall-bash-1.0.40-JjzPuQtpA1gDxygOUbFu35
depends:
    base-4.16.4.0 bytestring-0.11.4.0 containers-0.6.5.1
    dhall-1.41.2-DxjlnSEJkR2FDPUb7caFHV
    neat-interpolation-0.5.1.4-5IlEY3AtdVTLeTv0lfJ65i
    shell-escape-0.2.0-GKZq8uaRmlD69F3LuplKxx text-1.2.5.0

haddock-interfaces:   /usr/share/doc/dhall-bash/html/dhall-bash.haddock
haddock-html:         /usr/share/doc/dhall-bash/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> dhall-bash-1.0.40-281-riscv64.pkg.tar.zst: usr/share/haskell/register/dhall-bash.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 dhall-bash
version:              1.0.40
visibility:           public
id:                   dhall-bash-1.0.40-44SA47KSESDH931ZxdQOWJ
key:                  dhall-bash-1.0.40-44SA47KSESDH931ZxdQOWJ
license:              BSD-3-Clause
copyright:            2017 Gabriel Gonzalez
maintainer:           Gabriel439@gmail.com
author:               Gabriel Gonzalez
synopsis:             Compile Dhall to Bash
description:
    Use this package if you want to compile Dhall expressions to Bash.
    You can use this package as a library or an executable:

    * See the "Dhall.Bash" module if you want to use this package as a library

    * Use the @dhall-to-bash@ if you want an executable

    The "Dhall.Bash" module also contains instructions for how to use this
    package

category:             Compiler
abi:                  524d9588c5a7414e6a4575c581fff719
exposed:              True
exposed-modules:      Dhall.Bash
import-dirs:          /usr/lib/ghc-9.2.8/site-local/dhall-bash-1.0.40
library-dirs:         /usr/lib/ghc-9.2.8/site-local/dhall-bash-1.0.40
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/dhall-bash
hs-libraries:         HSdhall-bash-1.0.40-44SA47KSESDH931ZxdQOWJ
depends:
    base-4.16.4.0 bytestring-0.11.4.0 containers-0.6.5.1
    dhall-1.41.2-8joxPp720UY4JPqJUZgc6y
    neat-interpolation-0.5.1.4-FoHLeyx64Ek6faAulgi96Y
    shell-escape-0.2.0-L1Pji7hqRRQGmvwxRsCJGZ text-1.2.5.0

haddock-interfaces:   /usr/share/doc/dhall-bash/html/dhall-bash.haddock
haddock-html:         /usr/share/doc/dhall-bash/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
